<?php
  include ('funkcje_ksiazka_kz.php');
  // koszyk na zakupy potrzebuje sesji, zostaje więc ona rozpoczęta
  session_start();

  tworz_naglowek_html('Kasa');

  $typ_karty = $_POST['typ_karty'];
  $numer_karty = $_POST['numer_karty'];
  $miesiac_karty = $_POST['miesiac_karty'];
  $rok_karty = $_POST['rok_karty'];
  $nazwa_karty = $_POST['nazwa_karty'];

  if(($_SESSION['koszyk']) && ($typ_karty) && ($numer_karty) &&
     ($miesiac_karty) && ($rok_karty) && ($nazwa_karty)) {
    // wyświetl koszyk bez możliwości zmian
    wyswietl_koszyk($_SESSION['koszyk'], false, 0);

    wyswietl_dostawe(oblicz_koszt_dostawy());

    if(przetworz_karte($_POST)) {
      // opróżnij koszyk
      session_destroy();
      echo "<p>Dziękujemy za dokonanie zakupów. Zamówienie zostało przyjęte.</p>";
      wyswietl_przycisk("indeks.php", "kontynuacja", "Kontynuacja zakupów");
    } else {
    echo "<p>Dokonanie operacji niemożliwe. Proszę skontaktować się z wystawcą karty lub spróbować ponownie.</p>";
    wyswietl_przycisk("zakup.php", "powrot", "Powrót");
    }
  } else {
    echo "<p>Nie zostały wypełnione wszystkie pola, proszę spróbować ponownie.</p><hr />";
    wyswietl_przycisk("zakup.php", "powrot", "Powrót");
  }

  tworz_stopke_html();
?>